pub struct Config {
pub days: Vec<Day>,
}Fields
days: Vec<Day>Implementations
Sourceimpl Config
impl Config
Sourcepub fn set_day(&mut self, label: &str, date: OffsetDateTime)
pub fn set_day(&mut self, label: &str, date: OffsetDateTime)
Add/update a day to the config
The day is added if days doesn’t contain a day with the given label.
If a day with the same (trimmed) label is found its date is updated with the given date
Sourcepub fn remove_day(&mut self, label: &str)
pub fn remove_day(&mut self, label: &str)
Removes a day with the given label from the config
The label comparison ignores case and leading/trailing whitespace